=========================================================================
``psyclone.domain.lfric.transformations.lfric_raise_call_2_invoke_trans``
=========================================================================

.. automodule:: psyclone.domain.lfric.transformations.lfric_raise_call_2_invoke_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.lfric.transformations.lfric_raise_call_2_invoke_trans


Classes
=======

- :py:class:`LFRicRaiseCall2InvokeTrans`:
  Transform a generic PSyIR representation of an Algorithm-layer


.. autoclass:: LFRicRaiseCall2InvokeTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: LFRicRaiseCall2InvokeTrans
      :parts: 1
